@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -19,11 +19,10 @@
  *
  */
 
-
-
 package com.openexchange.imageconverter.client;
 
 import java.net.HttpURLConnection;
+import java.net.URL;
 import javax.net.ssl.HttpsURLConnection;
 import javax.net.ssl.SSLContext;
 import javax.net.ssl.SSLSocketFactory;
@@ -60,6 +59,7 @@ class ImageConverterApiProvider {
 
     /**
      * Initializes a new {@link ImageConverterAPIProvider}.
+     *
      * @param imageConverterRemoteValidator
      */
     ImageConverterApiProvider(
@@ -69,32 +69,27 @@ class ImageConverterApiProvider {
 
         super();
 
-        // Using own http(s) connection factory to use given SSLSocketfactory;
-        // since this SSLSocketfactory might be overridden by the Jersey impl. using
-        // the configured SSLContext, the originating SSLContext needs to be
-        // provided y the used ClientBuilder as well.
-        m_apiClient = new ApiClient(
-            (clientConfig) -> {
-                return (null != sslSocketFactory) ?
-                    clientConfig.connectorProvider(
-                        new HttpUrlConnectorProvider().connectionFactory((url) -> {
-                            final HttpURLConnection httpConnection = (HttpURLConnection) url.openConnection();
+        if (null != imageConverterClientConfig.getImageConverterServerURL()) {
+            // Using own http(s) connection factory to use given SSLSocketfactory;
+            // since this SSLSocketfactory might be overridden by the Jersey impl. using
+            // the configured SSLContext, the originating SSLContext needs to be
+            // provided y the used ClientBuilder as well.
+            m_apiClient = new ApiClient((clientConfig) -> {
+                return (null != sslSocketFactory) ? clientConfig.connectorProvider(new HttpUrlConnectorProvider().connectionFactory((url) -> {
+                    final HttpURLConnection httpConnection = (HttpURLConnection) url.openConnection();
 
-                            if (httpConnection instanceof HttpsURLConnection) {
-                                ((HttpsURLConnection) httpConnection).setSSLSocketFactory(sslSocketFactory);
-                            }
+                    if (httpConnection instanceof HttpsURLConnection) {
+                        ((HttpsURLConnection) httpConnection).setSSLSocketFactory(sslSocketFactory);
+                    }
 
-                            return httpConnection;
-                        })) :
-                            clientConfig;
-            },
-            (clientBuilder) -> {
-                return (null != sslContext) ?
-                    clientBuilder.sslContext(sslContext) :
-                        clientBuilder;
+                    return httpConnection;
+                })) : clientConfig;
+            }, (clientBuilder) -> {
+                return (null != sslContext) ? clientBuilder.sslContext(sslContext) : clientBuilder;
             });
+        }
 
-       implConfigure(imageConverterClientConfig);
+        implConfigure(imageConverterClientConfig);
     }
 
     /**
@@ -144,14 +139,18 @@ class ImageConverterApiProvider {
         final ApiClient apiClient = m_apiClient;
 
         if (null != apiClient) {
-            apiClient.setBasePath(imageConverterClientConfig.getImageConverterServerURL().toString());
+            final URL baseURL = imageConverterClientConfig.getImageConverterServerURL();
+
+            if (null != baseURL) {
+                apiClient.setBasePath(baseURL.toString());
+            }
+
             apiClient.setTempFolderPath(imageConverterClientConfig.getSpoolDir().getAbsolutePath());
             apiClient.setConnectTimeout(DEFAULT_CONNECT_TIMEOUT_MILLIS);
             apiClient.setReadTimeout(DEFAULT_READ_TIMEOUT_MILLIS);
         }
     }
 
-
     // - Members ---------------------------------------------------------------
 
     volatile private ApiClient m_apiClient;
