@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -19,8 +19,6 @@
  *
  */
 
-
-
 package com.openexchange.imageconverter.client;
 
 import static org.apache.commons.lang.ArrayUtils.isEmpty;
@@ -96,11 +94,6 @@ public class ImageConverterClient implements IImageClient {
         super();
 
         m_clientConfig = new ImageConverterClientConfig(configurationService);
-
-        if (!m_clientConfig.isValid()) {
-            throw OXException.general("Configuration service is available, but config property is not valid");
-        }
-
         m_apiProvider = new ImageConverterApiProvider(m_clientConfig, sslSocketFactory, sslContext);
         m_remoteValidator = new ImageConverterRemoteValidator(m_clientConfig, m_apiProvider);
     }
@@ -110,12 +103,10 @@ public class ImageConverterClient implements IImageClient {
      */
     @Override
     public void reloadConfiguration(ConfigurationService configService) {
-        if (null != m_clientConfig) {
-            m_clientConfig.reloadConfiguration(configService);
+        m_clientConfig.reloadConfiguration(configService);
 
-            m_apiProvider.updateConfiguration(m_clientConfig);
-            m_remoteValidator.updateRemoteURL(m_clientConfig.getImageConverterServerURL());
-        }
+        m_apiProvider.updateConfiguration(m_clientConfig);
+        m_remoteValidator.updateRemoteURL(m_clientConfig.getImageConverterServerURL());
     }
 
     /* (non-Javadoc)
@@ -123,9 +114,7 @@ public class ImageConverterClient implements IImageClient {
      */
     @Override
     public Interests getInterests() {
-        return (null != m_clientConfig) ?
-            m_clientConfig.getInterests() :
-                null;
+        return m_clientConfig.getInterests();
     }
 
     /*
@@ -144,11 +133,11 @@ public class ImageConverterClient implements IImageClient {
      * @see com.openexchange.imageconverter.api.IImageConverter#getImage(java.lang.String, java.lang.String, java.lang.String)
      */
     @Override
-    public InputStream getImage(final String imageKey, final String requestFormat, final String... context) throws ImageConverterException {
+    public InputStream getImage(final String imageKey, final String requestFormat, final String fileName, final String... context) throws ImageConverterException {
         final ImageConverterApi api = m_apiProvider.acquire();
         InputStream ret = null;
 
-        LOG.trace("IC client #getImage called (imageKey/requestFormat): {} / {}", imageKey, requestFormat);
+        LOG.trace("IC client #getImage called (imageKey/requestFormat/fileName): {} / {} / {}", imageKey, requestFormat, fileName);
 
         if (null != api) {
             try {
@@ -156,7 +145,7 @@ public class ImageConverterClient implements IImageClient {
                     File tmpResponseFile = null;
 
                     try {
-                        if (null != (tmpResponseFile = api.getImage(imageKey, requestFormat, implGetContext(context)))) {
+                        if (null != (tmpResponseFile = api.getImage(imageKey, requestFormat, fileName, implGetContext(context)))) {
                             ret = new ByteArrayInputStream(FileUtils.readFileToByteArray(tmpResponseFile));
                         }
                     } catch (ApiException | ProcessingException e) {
@@ -181,11 +170,11 @@ public class ImageConverterClient implements IImageClient {
      * @see com.openexchange.imageconverter.api.IImageConverter#getMetadata(java.lang.String, java.lang.String[])
      */
     @Override
-    public IMetadata getMetadata(String imageKey, String... context) throws ImageConverterException {
+    public IMetadata getMetadata(String imageKey, final String fileName, String... context) throws ImageConverterException {
         final ImageConverterApi api = m_apiProvider.acquire();
         IMetadata ret = null;
 
-        LOG.trace("IC client #getMetadata called (imageKey): {}", imageKey);
+        LOG.trace("IC client #getMetadata called (imageKey/fileName): {} / {}", imageKey, fileName);
 
         if (null != api) {
             try {
@@ -193,7 +182,7 @@ public class ImageConverterClient implements IImageClient {
                     File tmpResponseFile = null;
 
                     try {
-                        final ApiResponse<File> fileResponse = api.getMetadataWithHttpInfo(imageKey, implGetContext(context));
+                        final ApiResponse<File> fileResponse = api.getMetadataWithHttpInfo(imageKey, fileName, implGetContext(context));
 
                         if ((null != fileResponse) && (null != (tmpResponseFile = fileResponse.getData()))) {
                             try (final InputStream fileInputStm = FileUtils.openInputStream(tmpResponseFile);
@@ -226,11 +215,11 @@ public class ImageConverterClient implements IImageClient {
      * @see com.openexchange.imageconverter.api.IImageConverter#getImageAndMetadata(java.lang.String, java.lang.String, java.lang.String[])
      */
     @Override
-    public MetadataImage getImageAndMetadata(String imageKey, String requestFormat, String... context) throws ImageConverterException {
+    public MetadataImage getImageAndMetadata(String imageKey, String requestFormat, final String fileName, String... context) throws ImageConverterException {
         final ImageConverterApi api = m_apiProvider.acquire();
         MetadataImage ret = null;
 
-        LOG.trace("IC client #getImageAndMetadata called (imageKey/requestFormat): {} / {}", imageKey, requestFormat);
+        LOG.trace("IC client #getImageAndMetadata called (imageKey/requestFormat/fileName): {} / {} / {}", imageKey, requestFormat, fileName);
 
         if (null != api) {
             try {
@@ -238,7 +227,7 @@ public class ImageConverterClient implements IImageClient {
                     File tmpResponseFile = null;
 
                     try {
-                        final ApiResponse<File> fileResponse = api.getImageAndMetadataWithHttpInfo(imageKey, requestFormat, implGetContext(context));
+                        final ApiResponse<File> fileResponse = api.getImageAndMetadataWithHttpInfo(imageKey, requestFormat, fileName, implGetContext(context));
 
                         if ((null != fileResponse) && (null != (tmpResponseFile = fileResponse.getData()))) {
                             try (final InputStream fileInputStm = FileUtils.openInputStream(tmpResponseFile)) {
@@ -267,10 +256,10 @@ public class ImageConverterClient implements IImageClient {
      * @see com.openexchange.imageconverter.api.IImageConverter#cacheImage(java.lang.String, java.lang.String, java.io.InputStream)
      */
     @Override
-    public void cacheImage(final String imageKey, final InputStream srcImageStm, final String... context) throws ImageConverterException {
+    public void cacheImage(final String imageKey, final InputStream srcImageStm, final String fileName, final String... context) throws ImageConverterException {
         final ImageConverterApi api = m_apiProvider.acquire();
 
-        LOG.trace("IC client #cacheImage called (imageKey): {}", imageKey);
+        LOG.trace("IC client #cacheImage called (imageKey / fileName): {} / {}", imageKey, fileName);
 
         if (null != api) {
             try {
@@ -279,14 +268,14 @@ public class ImageConverterClient implements IImageClient {
 
                     if (null != tmpInputFile) {
                         try {
-                            api.cacheImage(imageKey, tmpInputFile, implGetContext(context));
+                            api.cacheImage(imageKey, tmpInputFile, fileName, implGetContext(context));
                         } catch (ApiException | ProcessingException e) {
                             implHandleAPIException("Error in remote calling ImageConverter#cacheImage", e);
                         } finally {
                             FileUtils.deleteQuietly(tmpInputFile);
                         }
                     } else if (LOG.isWarnEnabled()) {
-                        LOG.warn("InputStream in call to ImageConverter#cacheImage is empty (imageKey): {}", imageKey);
+                        LOG.warn("InputStream in call to ImageConverter#cacheImage is empty (imageKey/fileName): {} / {}", imageKey, fileName);
                     }
                 }
             } finally {
@@ -301,11 +290,11 @@ public class ImageConverterClient implements IImageClient {
      * @see com.openexchange.imageconverter.api.IImageConverter#cacheAndGetImage(java.lang.String, java.lang.String, java.lang.String, java.io.InputStream)
      */
     @Override
-    public InputStream cacheAndGetImage(final String imageKey, final String requestFormat, final InputStream srcImageStm, final String... context) throws ImageConverterException {
+    public InputStream cacheAndGetImage(final String imageKey, final String requestFormat, final InputStream srcImageStm, final String fileName, final String... context) throws ImageConverterException {
         final ImageConverterApi api = m_apiProvider.acquire();
         InputStream ret = null;
 
-        LOG.trace("IC client #cacheAndGetImage called (imageKey/requestFormat): {} / {}", imageKey, requestFormat);
+        LOG.trace("IC client #cacheAndGetImage called (imageKey/requestFormat/fileName): {} / {} / {}", imageKey, requestFormat, fileName);
 
         if (null != api) {
             try {
@@ -317,7 +306,7 @@ public class ImageConverterClient implements IImageClient {
                             File tmpResponseFile = null;
 
                             try {
-                                if (null != (tmpResponseFile = api.cacheAndGetImage(imageKey, requestFormat, tmpInputFile, implGetContext(context)))) {
+                                if (null != (tmpResponseFile = api.cacheAndGetImage(imageKey, requestFormat, tmpInputFile, fileName, implGetContext(context)))) {
                                     ret = new ByteArrayInputStream(FileUtils.readFileToByteArray(tmpResponseFile));
                                 }
                             } catch (ApiException | ProcessingException e) {
@@ -329,10 +318,10 @@ public class ImageConverterClient implements IImageClient {
                                 FileUtils.deleteQuietly(tmpResponseFile);
                             }
                         } else if (LOG.isWarnEnabled()) {
-                            LOG.warn("InputStream in call to ImageConverter#cacheAndGetImage is empty (imageKey): {}", imageKey);
+                            LOG.warn("InputStream in call to ImageConverter#cacheAndGetImage is empty (imageKey/fileName): {} / {}", imageKey, fileName);
                         }
                     } else {
-                        ret = getImage(imageKey, requestFormat, context);
+                        ret = getImage(imageKey, requestFormat, fileName, context);
                     }
                 }
             } finally {
@@ -349,11 +338,11 @@ public class ImageConverterClient implements IImageClient {
      * @see com.openexchange.imageconverter.api.IImageConverter#cacheAndGetImageAndMetadata(java.lang.String, java.lang.String, java.io.InputStream, java.lang.String[])
      */
     @Override
-    public MetadataImage cacheAndGetImageAndMetadata(String imageKey, String requestFormat, InputStream srcImageStm, String... context) throws ImageConverterException {
+    public MetadataImage cacheAndGetImageAndMetadata(String imageKey, String requestFormat, InputStream srcImageStm, final String fileName, String... context) throws ImageConverterException {
         final ImageConverterApi api = m_apiProvider.acquire();
         MetadataImage ret = null;
 
-        LOG.trace("IC client #cacheAndGetImageAndMetadata called (imageKey/requestFormat): {} / {}", imageKey, requestFormat);
+        LOG.trace("IC client #cacheAndGetImageAndMetadata called (imageKey/requestFormat/fileName): {} / {} / {}", imageKey, requestFormat, fileName);
 
         if (null != api) {
             try {
@@ -365,7 +354,7 @@ public class ImageConverterClient implements IImageClient {
                             File tmpResponseFile = null;
 
                             try {
-                                final ApiResponse<File> fileResponse = api.cacheAndGetImageAndMetadataWithHttpInfo(imageKey, requestFormat, tmpInputFile, implGetContext(context));
+                                final ApiResponse<File> fileResponse = api.cacheAndGetImageAndMetadataWithHttpInfo(imageKey, requestFormat, tmpInputFile, fileName, implGetContext(context));
 
                                 if ((null != fileResponse) && (null != (tmpResponseFile = fileResponse.getData()))) {
                                     try (final InputStream fileInputStm = FileUtils.openInputStream(tmpResponseFile)) {
@@ -381,7 +370,7 @@ public class ImageConverterClient implements IImageClient {
                                 FileUtils.deleteQuietly(tmpResponseFile);
                             }
                         } else if (LOG.isWarnEnabled()) {
-                            LOG.warn("InputStream in call to ImageConverter#cacheAndGetImageAndMetadata is empty (imageKey): {}", imageKey);
+                            LOG.warn("InputStream in call to ImageConverter#cacheAndGetImageAndMetadata is empty (imageKey/fileName): {} / {}", imageKey, fileName);
                         }
                     }
                 }
@@ -550,6 +539,13 @@ public class ImageConverterClient implements IImageClient {
 
     // - public interface ------------------------------------------------------
 
+    /**
+     * @return
+     */
+    @NonNull public ImageConverterClientConfig getConfig() {
+        return m_clientConfig;
+    }
+
     /**
      * @return
      */
