@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -19,8 +19,6 @@
  *
  */
 
-
-
 package com.openexchange.imageconverter.client;
 
 import static com.openexchange.imageconverter.client.ImageConverterClient.LOG;
@@ -39,6 +37,7 @@ import org.apache.commons.io.FileUtils;
 import org.apache.commons.lang.ArrayUtils;
 
 import com.openexchange.annotation.NonNull;
+import com.openexchange.annotation.Nullable;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.config.Interests;
 import com.openexchange.config.Reloadables;
@@ -120,7 +119,7 @@ public final class ImageConverterClientConfig {
         boolean ret = false;
 
         try {
-            ret =(isValid() && m_imageConverterServerURL.equals(new URL(REMOTE_TEST_URL)));
+            ret = (isValid() && m_imageConverterServerURL.equals(new URL(REMOTE_TEST_URL)));
         } catch (@SuppressWarnings("unused") MalformedURLException e) {
             // ok, should not happen with check of test Url
         }
@@ -131,15 +130,15 @@ public final class ImageConverterClientConfig {
     /**
      * @return
      */
-    public URL getImageConverterServerURL() {
+    @Nullable public URL getImageConverterServerURL() {
         return m_imageConverterServerURL;
     }
 
     /**
      * @return
      */
-    public File getSpoolDir() {
-        return (m_running.get() ? m_spoolDir : FileUtils.getTempDirectory());
+    @NonNull public File getSpoolDir() {
+        return (m_running.get() && (null != m_spoolDir) ? m_spoolDir : FileUtils.getTempDirectory());
     }
 
     /* (non-Javadoc)
@@ -186,9 +185,8 @@ public final class ImageConverterClientConfig {
             }
 
             if ((null == m_imageConverterServerURL) || (m_imageConverterServerURL.toString().length() < 1)) {
-                LOG.error("IC client remoteDocumentConverterUrl property is empty or not set at all. Client is not able to perform conversions until a valid Url is set! {}", m_imageConverterServerURL);
+                LOG.error("IC client remoteImageConverterUrl property is empty or not set at all. Client is not able to perform conversions until a valid Url is set! {}", m_imageConverterServerURL);
             }
-
         }
 
         if (itemsToRead.contains(CONFIGITEM_SPOOL_PATH)) {
