@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -19,10 +19,9 @@
  *
  */
 
-
-
 package com.openexchange.imageconverter.client.osgi;
 
+import org.eclipse.microprofile.health.HealthCheck;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import com.google.common.base.Throwables;
@@ -31,6 +30,7 @@ import com.openexchange.config.Reloadable;
 import com.openexchange.exception.OXException;
 import com.openexchange.imageconverter.api.IImageClient;
 import com.openexchange.imageconverter.api.IMetadataReader;
+import com.openexchange.imageconverter.client.ImageConverterClientHealthCheck;
 import com.openexchange.imageconverter.client.ImageConverterClient;
 import com.openexchange.imageconverter.client.Services;
 import com.openexchange.net.ssl.SSLSocketFactoryProvider;
@@ -106,6 +106,7 @@ public class ImageConverterClientActivator extends HousekeepingActivator {
             // register IImageClient service as Reloadable configuration
             // service for changing the remote URL config item at runtime
             registerService(Reloadable.class, m_imageConverterClient);
+            registerService(HealthCheck.class, new ImageConverterClientHealthCheck(m_imageConverterClient));
 
             openTrackers();
 
